@@ -386,6 +386,9 @@ SERVICE_VERSIONS = {
     "ivld": [
         "2021-09-03"
     ],
+    "keewidb": [
+        "2022-03-08"
+    ],
     "kms": [
         "2019-01-18"
     ],
